@@ -270,6 +270,7 @@ __extras = {
     "ASCII_ALPHANUMERIC": ASCII_ALPHANUMERIC,
     "ASCII_TABLE": ASCII_TABLE,
     "ASCII_TABLE_128": ASCII_TABLE_128,
+    "AUTHENTICATION": "authentication",
     "BASE_36_TABLE": BASE_36_TABLE,
     "BASE_64_TABLE": BASE_64_TABLE,
     "BYTES_TABLE": BYTES_TABLE,
@@ -307,7 +308,7 @@ __extras = {
     "METATAG": sha3_256(f"__metatags__{NONE}".encode()).hexdigest(),
     "NEW_CONTACT": "new_contact",
     "NEXT_KEYED_PASSWORD": "next_keyed_password",
-    "NEXT_SALT": "next_salt",
+    "NEXT_PASSWORD_SALT": "next_password_salt",
     "NO_PROFILE_OR_CORRUPT": "Profile doesn't exist or is corrupt.",
     "NONE": NONE,
     "NUM": NUM,
